/*
 * Copyright 2025 cronn GmbH
 * SPDX-License-Identifier: AGPL-3.0-only
 */

package de.eshg.schoolentry.importer;

import de.eshg.lib.xlsximport.XlsxColumn;

public enum PastProcedureListColumn implements XlsxColumn {
  LAST_NAME("Nachname"),
  FIRST_NAME("Vorname"),
  DATE_OF_BIRTH("Geburtsdatum"),
  GENDER("Geschlecht"),
  STREET("Straße"),
  HOUSE_NUMBER("Hausnummer"),
  POSTAL_CODE("PLZ"),
  CITY("Ort"),
  ADDRESS_ADDITION("Adresszusatz"),
  PROCEDURE_TYPE("Vorgangsart"),
  EXAMINATION_DATE("Untersuchungsdatum"),
  SIBLINGS("KIH"),
  COUNTRY_OF_BIRTH_CHILD("GEBKI"),
  NATIONALITY_CHILD("STAKI"),
  COUNTRY_OF_BIRTH_P1("GEBET1"),
  NATIONALITY_P1("STAET1"),
  COUNTRY_OF_BIRTH_P2("GEBET2"),
  NATIONALITY_P2("STAET2"),
  MIGRATION_BACKGROUND("MIG"),
  DAYCARE("KT"),
  PRELIMINARY_COURSE("VLK"),
  BIRTH_WEIGHT("GG"),
  INTEGRATION_PLACE("IP"),
  EARLY_SUPPORT("FF"),
  ERGO_THERAPY("ERGO"),
  SPEECH_THERAPY("LOGO"),
  PHYSIO_THERAPY("KG"),
  CHILD_LANGUAGE_SCREENING("KISS"),
  U2("U2E"),
  U3("U3E"),
  U4("U4E"),
  U5("U5E"),
  U6("U6E"),
  U7("U7E"),
  U7A("U7A"),
  U8("U8E"),
  U9("U9E"),
  VACCINATION_SCHEME("Impfschema"),
  TETANUS("Tet"),
  DIPHTERIA("Dip"),
  PERTUSSIS("Per"),
  POLIO("Pol"),
  HIB("HIB"),
  HEPATITIS_B("HBV"),
  MMR("MMR"),
  VARICELLA("Vari"),
  MENINGOCOCCUS_C("MenC"),
  PNEUMOCOCCUS("Pneumo"),
  HEPATITIS_A("HAV"),
  TBE("FSME"),
  ROTA("Rota"),
  MENINGOCOCCUS_B("MenB"),
  PERKOMBI_HBV("PerkombiHBV"),
  EYE_EXAMINATION("VISCH"),
  LANG_EXAMINATION("VISTR"),
  ISHIHARA_EXAMINATION("FARB"),
  HEARING_TEST("AUDIO"),
  SYSTOLE("RRSYS"),
  DIASTOLE("RRDIA"),
  HEIGHT("GROE"),
  WEIGHT("GEWI"),
  NUTRITIONAL_CONDITION("EZ"),
  SKIN("DERM"),
  MUSCULATOR_SKELETON("MUSK"),
  EAR_NOSE_THROAT("HNO"),
  RESPIRATORY_CARDIOVASCULAR("AHK"),
  ABDOMEN("ABD"),
  NEUROLOGY("NEU"),
  METABOLISM("ENDO"),
  JUMP_COUNT("KOORD"),
  VISUO_MOTOR("VISMOT"),
  GROSS_MOTOR("GROMO"),
  FINE_MOTOR("FEIMO"),
  PRIMARY_LANGUAGE("ESPR"),
  IN_GERMANY_SINCE("WOHND"),
  FAMILY_LANGUAGE("FAMSPR"),
  GERMAN_PRIMARY_CARER("SPRBP"),
  GERMAN_CHILD("SPRDEU"),
  ARTICULATION("DYS"),
  PSEUDOWORDS("PSWOE"),
  PREPOSITIONS("PRAEP"),
  PLURALS("PLUR"),
  SPEECH_RESULT("SPR"),
  VISUAL_PERCEPTION_POINTS("VISPER"),
  AUDITIVE_PROCESSING("AUDWA"),
  VISUAL_PERCEPTION_RESULT("VISWA"),
  COUNTING("ZAEHL"),
  QUANTITY_KNOWLEDGE("MENG"),
  SELECTIVE_ATTENTION("SELAUFM"),
  KNOWLEDGE_THINKING("WISSDE"),
  PSYCHOLOGICAL_BEHAVIOUR("PSYVER"),
  CHRONIC_DISEASE("CHKR"),
  CHRONIC_DISEASE_ICD10_1("DIAGCH1"),
  CHRONIC_DISEASE_ICD10_2("DIAGCH2"),
  CHRONIC_DISEASE_ICD10_3("DIAGCH3"),
  DISABILITY("BEHI"),
  DISABILITY_TYPE("BEHIART"),
  DISABILITY_ICD10_1("DIAGB1"),
  DISABILITY_ICD10_2("DIAGB2"),
  DISABILITY_ICD10_3("DIAGB3"),
  VACCINATION_ADVICE("IMPF"),
  RE_INTRODUCTION("WSPR"),
  SCHOOL_COUNSELING("SCHB"),
  INFO_LETTER("INFO"),
  MOTOR_PROMOTION("MOTO"),
  LANGUAGE_ADVICE("SPRF"),
  NUTRITIONAL_ADVICE("ERNB"),
  EDUCATIONAL_ADVICE("ERZB"),
  SOCIAL_SERVICE("SOZD"),
  OTHER_SUPPORT("SOHI"),
  EXTRA_EFFORT("MEHR"),
  SCHOOL_RECOMMENDATION("SCHULEMPF"),
  STATUS(STATUS_COLUMN_HEADER, Necessity.ADD_IF_MISSING, STATUS_COLUMN_HEADER_WIDTH),
  PROCEDURE_ID(PROCEDURE_COLUMN_HEADER, Necessity.ADD_IF_MISSING, UUID_COLUMN_WIDTH),
  REFERENCE_ID(REFERENCE_COLUMN_HEADER, Necessity.ADD_IF_MISSING, UUID_COLUMN_WIDTH),
  ;

  private final String header;
  private final Necessity necessity;
  private final int columnWidth;

  PastProcedureListColumn(String header, Necessity necessity, int columnWidth) {
    this.header = header;
    this.necessity = necessity;
    this.columnWidth = columnWidth;
  }

  PastProcedureListColumn(String header) {
    this(header, Necessity.REQUIRED, 0);
  }

  @Override
  public String getHeader() {
    return header;
  }

  @Override
  public Necessity getNecessity() {
    return necessity;
  }

  @Override
  public int getColumnWidth() {
    return columnWidth;
  }
}
