/**
 * Copyright 2025 SCOOP Software GmbH, cronn GmbH
 * SPDX-License-Identifier: AGPL-3.0-only
 */

import { RequiresChildren } from "@eshg/lib-portal/types/react";
import { Sheet, Stack, Typography } from "@mui/joy";
import { SxProps } from "@mui/joy/styles/types";

import { theme } from "@/lib/baseModule/theme/theme";
import { byBreakpoint } from "@/lib/shared/breakpoints";
import { ContentSheetTitle } from "@/lib/shared/components/layout/contentSheet";

interface FormSheetProps extends RequiresChildren {
  "data-testid"?: string;
}

export function FormSheet(props: FormSheetProps) {
  return (
    <Sheet
      component="section"
      sx={{
        [theme.breakpoints.down("sm")]: {
          borderRadius: 0,
        },
      }}
      data-testid={props["data-testid"] ?? "form-sheet"}
    >
      <Stack gap={3}>{props.children}</Stack>
    </Sheet>
  );
}

interface FormSheetTitleProps extends RequiresChildren {
  requiredTitle?: string;
  sx?: SxProps;
}

export function FormSheetTitle(props: FormSheetTitleProps) {
  return (
    <Stack gap={byBreakpoint({ mobile: 1, desktop: 0 })} sx={props.sx}>
      <ContentSheetTitle>{props.children}</ContentSheetTitle>
      {props.requiredTitle && (
        <Typography
          level="body-xs"
          fontWeight={400}
          sx={{ textAlign: "right" }}
        >
          {props.requiredTitle}
        </Typography>
      )}
    </Stack>
  );
}
