/**
 * Copyright 2025 cronn GmbH
 * SPDX-License-Identifier: Apache-2.0
 */

import { ensureArray } from "@eshg/lib-portal/helpers/guards";
import { usePathname, useRouter, useSearchParams } from "next/navigation";
import { useCallback } from "react";
import { isNonNullish } from "remeda";

export type SearchParamValue =
  | string
  | number
  | string[]
  | number[]
  | null
  | undefined;

export interface SearchParamReplacement {
  name: string;
  value: SearchParamValue;
}

export function useReplaceSearchParams() {
  const searchParams = useSearchParams();
  const pathname = usePathname();
  const router = useRouter();

  function replaceSearchParams(
    searchParamReplacements: SearchParamReplacement[],
  ) {
    const newSearchParams = new URLSearchParams(searchParams);
    searchParamReplacements.forEach((replacement) => {
      newSearchParams.delete(replacement.name);
      if (isNonNullish(replacement.value)) {
        const values = ensureArray(replacement.value);
        values.forEach((value) => {
          const stringValue = String(value).trim();
          if (stringValue.length > 0) {
            newSearchParams.append(replacement.name, stringValue);
          }
        });
      }
    });
    router.replace(`${pathname}?${newSearchParams.toString()}`);
  }

  return useCallback(replaceSearchParams, [searchParams, pathname, router]);
}
