/**
 * Copyright 2025 SCOOP Software GmbH, cronn GmbH
 * SPDX-License-Identifier: AGPL-3.0-only
 */

"use client";

import type {
  ApiInspectionAppointment,
  ApiInspectionResource,
  ApiInspectionTravelTime,
} from "@eshg/inspection-api";
import { useState } from "react";

import { ResourceSidebar } from "@/lib/businessModules/inspection/components/inspection/planning/resource/ResourceSidebar";
import { ResourcesTable } from "@/lib/businessModules/inspection/components/inspection/planning/resource/ResourcesTable";
import { InfoTile } from "@/lib/shared/components/infoTile/InfoTile";
import { InfoTileAddButton } from "@/lib/shared/components/infoTile/InfoTileAddButton";

export interface ResourceTileProps {
  readonly?: boolean;
  procedureId: string;
  inspectionResources: ApiInspectionResource[];
  plannedAppointment?: ApiInspectionAppointment;
  standardBufferTime?: number;
  travelTime?: ApiInspectionTravelTime;
}

export function ResourceTile({
  readonly,
  procedureId,
  inspectionResources,
  plannedAppointment,
  standardBufferTime,
  travelTime,
}: Readonly<ResourceTileProps>) {
  const [open, setOpen] = useState(false);

  return (
    <InfoTile
      name="resource-header"
      title="Ressourcen"
      footer={
        !readonly && (
          <InfoTileAddButton onClick={() => setOpen(true)}>
            Ressource hinzufügen
          </InfoTileAddButton>
        )
      }
    >
      {inspectionResources.length > 0 && (
        <ResourcesTable
          readonly={readonly}
          data={inspectionResources}
          procedureId={procedureId}
        />
      )}

      {open && (
        <ResourceSidebar
          open
          procedureId={procedureId}
          plannedAppointment={plannedAppointment}
          standardBufferTime={standardBufferTime}
          travelTime={travelTime}
          onClose={() => setOpen(false)}
        />
      )}
    </InfoTile>
  );
}
