/**
 * Copyright 2025 cronn GmbH
 * SPDX-License-Identifier: AGPL-3.0-only
 */

"use client";

import { ButtonBar } from "@eshg/lib-employee-portal";
import { FormPlus } from "@eshg/lib-portal/components/form/FormPlus";
import { InputField } from "@eshg/lib-portal/components/formFields/InputField";
import { NavigationLink } from "@eshg/lib-portal/components/navigation/NavigationLink";
import { Add } from "@mui/icons-material";
import SearchIcon from "@mui/icons-material/Search";
import { Button } from "@mui/joy";
import { Formik } from "formik";

import { MedicalRegistryImportButton } from "@/lib/businessModules/medicalRegistry/components/procedures/import/MedicalRegistryImportButton";
import { routes } from "@/lib/businessModules/medicalRegistry/shared/routes";
import { FilterButton } from "@/lib/shared/components/buttons/FilterButton";
import { UseFilterSettings } from "@/lib/shared/components/filterSettings/useFilterSettings";

interface MedicalRegistryEntryOverviewControlProps {
  filterSettings: UseFilterSettings;
  toggleActivePanel: (panelName: "filters" | "entrySearch") => void;
  activePanel: "filters" | "entrySearch" | undefined;
  onNameSearch: (name: string) => void;
}

export function MedicalRegistryEntryOverviewControls(
  props: MedicalRegistryEntryOverviewControlProps,
) {
  const isEntrySearch = props.activePanel === "entrySearch";

  return (
    <ButtonBar
      left={
        <Formik
          initialValues={{
            name: "",
          }}
          onSubmit={({ name }) => props.onNameSearch(name)}
        >
          <FormPlus
            sx={{
              display: "flex",
              direction: "row",
              gap: 2,
            }}
          >
            {isEntrySearch && (
              <InputField
                label={null}
                placeholder="Suche"
                aria-label="Suche"
                name="name"
                type="text"
                startDecorator={<SearchIcon />}
              />
            )}
            {!isEntrySearch && (
              <FilterButton
                {...props.filterSettings.filterButtonProps}
                isFilterVisible={props.activePanel === "filters"}
                onClick={() => props.toggleActivePanel("filters")}
                activeFilters={
                  props.filterSettings.filterButtonProps.activeFilters
                }
              />
            )}
            {!isEntrySearch && (
              <Button onClick={() => props.toggleActivePanel("entrySearch")}>
                Suche
              </Button>
            )}
            {isEntrySearch && <Button type="submit">Suchen</Button>}
            {isEntrySearch && (
              <Button
                variant="outlined"
                onClick={() => props.toggleActivePanel("entrySearch")}
              >
                Abbrechen
              </Button>
            )}
          </FormPlus>
        </Formik>
      }
      right={
        !isEntrySearch && (
          <>
            <MedicalRegistryImportButton />
            <NavigationLink href={routes.procedures.create} passHref>
              <Button startDecorator={<Add />}>Eintrag erstellen</Button>
            </NavigationLink>
          </>
        )
      }
    />
  );
}
