/**
 * Copyright 2025 cronn GmbH
 * SPDX-License-Identifier: AGPL-3.0-only
 */

import { ContentPanel } from "@eshg/lib-employee-portal";
import { ReactNode } from "react";

import { ProcedureDetails } from "@/lib/businessModules/schoolEntry/api/models/ProcedureDetails";
import { CloseProcedureModal } from "@/lib/businessModules/schoolEntry/features/procedures/procedureDetails/CloseProcedureModal";
import { DeleteProcedureModal } from "@/lib/businessModules/schoolEntry/features/procedures/procedureDetails/DeleteProcedureModal";
import { ReopenProcedureModal } from "@/lib/businessModules/schoolEntry/features/procedures/procedureDetails/ReopenProcedureModal";
import { OpenModalButton } from "@/lib/shared/components/buttons/OpenModalButton";

export function ProcedureActionsPanel(props: { procedure: ProcedureDetails }) {
  const buttons: ReactNode[] = [];

  if (!props.procedure.isClosed) {
    buttons.push(
      <OpenModalButton
        key="closeProcedure"
        renderModal={(modalProps) => (
          <CloseProcedureModal procedure={props.procedure} {...modalProps} />
        )}
      >
        Vorgang abschließen
      </OpenModalButton>,
    );
  }

  if (props.procedure.isClosed) {
    buttons.push(
      <OpenModalButton
        key="reopenProcedure"
        renderModal={(modalProps) => (
          <ReopenProcedureModal procedure={props.procedure} {...modalProps} />
        )}
        color="danger"
      >
        Vorgang wiedereröffnen
      </OpenModalButton>,
    );
  }

  if (props.procedure.isDeletable) {
    buttons.push(
      <OpenModalButton
        key="deleteProcedure"
        renderModal={(modalProps) => (
          <DeleteProcedureModal procedure={props.procedure} {...modalProps} />
        )}
        color="danger"
      >
        Vorgang löschen
      </OpenModalButton>,
    );
  }

  if (buttons.length === 0) {
    return null;
  }

  return <ContentPanel>{buttons}</ContentPanel>;
}
