/**
 * Copyright 2025 cronn GmbH
 * SPDX-License-Identifier: Apache-2.0
 */

import { Add } from "@mui/icons-material";
import { Button, Divider, Grid } from "@mui/joy";
import { FieldArray } from "formik";
import { Fragment } from "react";

import {
  AppointmentBlockFormWithDays,
  AppointmentBlockGroupValuesWithDays,
  emptyAppointmentBlockGroup,
} from "@/lib/shared/components/appointmentBlocks/AppointmentBlockFormWithDays";
import { FormGroupGrid } from "@/lib/shared/components/form/FormGroupGrid";

const APPOINTMENT_BLOCK_GROUP_MAX_LENGTH = 5;

interface AppointmentBlockFieldArrayWithDaysProps {
  name: string;
  appointmentBlocks: AppointmentBlockGroupValuesWithDays[];
}

export function AppointmentBlockFieldArrayWithDays(
  props: Readonly<AppointmentBlockFieldArrayWithDaysProps>,
) {
  const hasReachedAppointmentBlockLimit =
    props.appointmentBlocks.length >= APPOINTMENT_BLOCK_GROUP_MAX_LENGTH;

  return (
    <FieldArray name={props.name}>
      {({ remove, push }) => (
        <>
          {props.appointmentBlocks.map((_value, index) => (
            <Fragment key={index}>
              <FormGroupGrid data-testid="appointmentBlockForm">
                <AppointmentBlockFormWithDays
                  name={`appointmentBlocks.${index}`}
                  removeBlock={() => remove(index)}
                  blockCount={props.appointmentBlocks.length}
                />
              </FormGroupGrid>
              {props.appointmentBlocks.length > 1 &&
                index < props.appointmentBlocks.length - 1 && <Divider />}
            </Fragment>
          ))}
          <>
            <Divider />
            {!hasReachedAppointmentBlockLimit && (
              <Grid xs={2}>
                <Button
                  variant="outlined"
                  startDecorator={<Add />}
                  onClick={() => {
                    if (!hasReachedAppointmentBlockLimit) {
                      push(emptyAppointmentBlockGroup());
                    }
                  }}
                >
                  Terminblock hinzufügen
                </Button>
              </Grid>
            )}
          </>
        </>
      )}
    </FieldArray>
  );
}
