/**
 * Copyright 2025 cronn GmbH
 * SPDX-License-Identifier: Apache-2.0
 */

import { useHandledMutation } from "@eshg/lib-portal/api/useHandledMutation";
import { useSnackbar } from "@eshg/lib-portal/components/snackbar/SnackbarProvider";
import { ApiCreateApprovalRequestRequest } from "@eshg/lib-procedures-api";

import { FileClient } from "@/lib/shared/components/procedures/progress-entries/types";

export function useDeleteFile(fileApi: FileClient) {
  const snackbar = useSnackbar();
  return useHandledMutation({
    mutationFn: async (fileId: string) => await fileApi.deleteFile(fileId),
    onSuccess: () => {
      snackbar.confirmation("Datei erfolgreich gelöscht.");
    },
  });
}

export function useRequestFileDeletion(fileApi: FileClient) {
  const snackbar = useSnackbar();
  return useHandledMutation({
    mutationFn: async ({
      fileId,
      createApprovalRequest,
    }: {
      fileId: string;
      createApprovalRequest: ApiCreateApprovalRequestRequest;
    }) => {
      return await fileApi.requestFileDeletion(fileId, createApprovalRequest);
    },
    onSuccess: () =>
      snackbar.confirmation("Löschanfrage erfolgreich gesendet."),
  });
}
