/**
 * Copyright 2025 cronn GmbH
 * SPDX-License-Identifier: Apache-2.0
 */

import {
  OnBeforeNavigateProps,
  useNavigation,
} from "@eshg/lib-portal/components/navigation/NavigationContext";
import { useEffect } from "react";

export function useConfirmNavigationEffect(
  triggerLeaveConfirmation: boolean,
  onBeforeNavigateProps?: OnBeforeNavigateProps,
): void {
  const { setCanNavigate, setOnBeforeNavigateProps } = useNavigation();
  useEffect(() => {
    setOnBeforeNavigateProps(onBeforeNavigateProps);
    setCanNavigate(!triggerLeaveConfirmation);
    return () => {
      setOnBeforeNavigateProps(undefined);
      setCanNavigate(true);
    };
  }, [
    triggerLeaveConfirmation,
    setCanNavigate,
    setOnBeforeNavigateProps,
    onBeforeNavigateProps,
  ]);
}
